@@ -4,7 +4,8 @@
 //C- Copyright (c) 2006  Leon Bottou
 //C-
 //C- This software is subject to, and may be distributed under, the
-//C- GNU General Public License. The license should have
+//C- GNU General Public License, either version 2 of the license,
+//C- or (at your option) any later version. The license should have
 //C- accompanied the software or you may obtain a copy of the license
 //C- from the Free Software Foundation at http://www.fsf.org .
 //C-
@@ -14,7 +15,7 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: qdjviewprefs.cpp,v 1.34 2007/01/11 04:47:04 leonb Exp $
+// $Id: qdjviewprefs.cpp,v 1.39 2007/10/22 04:04:55 leonb Exp $
 
 #if AUTOCONF
 # include "config.h"
@@ -84,6 +85,7 @@ QDjViewPrefs::defaultTools
 = TOOLBAR_TOP | TOOLBAR_BOTTOM
 | TOOL_ZOOMCOMBO | TOOL_ZOOMBUTTONS
 | TOOL_PAGECOMBO | TOOL_PREVNEXT | TOOL_FIRSTLAST 
+| TOOL_BACKFORW
 | TOOL_OPEN | TOOL_FIND | TOOL_SELECT
 | TOOL_PRINT | TOOL_LAYOUT
 | TOOL_WHATSTHIS;
@@ -210,7 +212,7 @@ QDjViewPrefs::stringToModifiers(QString s)
       key = key.toLower();
       if (key == "shift")
         m |= Qt::ShiftModifier;
-#if Q_WS_MAC
+#ifdef Q_WS_MAC
       else if (key == "control")
         m |= Qt::MetaModifier;
       else if (key == "command")
@@ -301,7 +303,11 @@ QDjViewPrefs::loadGroup(QSettings &s, QString name, Saved &saved)
 void
 QDjViewPrefs::load()
 {
-  QSettings s(DJVIEW_ORG, DJVIEW_APP);
+  QSettings s;
+
+  int versionFix = 0;
+  if (s.contains("versionFix"))
+    versionFix = s.value("versionFix").toInt();
 
   loadGroup(s, "forEmbeddedPlugin", forEmbeddedPlugin);
   loadGroup(s, "forFullPagePlugin", forFullPagePlugin);
@@ -312,6 +318,8 @@ QDjViewPrefs::load()
     windowSize = s.value("windowSize").toSize();
   if (s.contains("tools"))
     tools = stringToTools(s.value("tools").toString());
+  if (versionFix < 0x40200)
+    tools |= TOOL_BACKFORW;
   if (s.contains("gamma"))
     gamma = s.value("gamma").toDouble();
   if (s.contains("cacheSize"))
@@ -360,6 +368,9 @@ QDjViewPrefs::load()
     printCollate = s.value("printCollate").toBool();
   if (s.contains("printReverse"))
     printCollate = s.value("printReverse").toBool();
+
+  if (s.contains("recentFiles"))
+    recentFiles = s.value("recentFiles").toStringList();
 }
 
 
@@ -381,10 +392,16 @@ QDjViewPrefs::saveGroup(QSettings &s, QString name, Saved &saved)
 void
 QDjViewPrefs::save(void)
 {
-  QSettings s(DJVIEW_ORG, DJVIEW_APP);
+  QSettings s;
   
   s.setValue("version", versionString());
 
+  int versionFix = 0;
+  if (s.contains("versionFix"))
+    versionFix = s.value("versionFix").toInt();
+  if (DJVIEW_VERSION > versionFix)
+    s.setValue("versionFix", DJVIEW_VERSION);
+  
   saveGroup(s, "forEmbeddedPlugin", forEmbeddedPlugin);
   saveGroup(s, "forFullPagePlugin", forFullPagePlugin);
   saveGroup(s, "forStandalone", forStandalone);
@@ -416,6 +433,8 @@ QDjViewPrefs::save(void)
   s.setValue("printFile", printFile);
   s.setValue("printCollate", printCollate);
   s.setValue("printReverse", printReverse);
+
+  s.setValue("recentFiles", recentFiles);
 }
 
 
