@@ -4,7 +4,8 @@
 //C- Copyright (c) 2006  Leon Bottou
 //C-
 //C- This software is subject to, and may be distributed under, the
-//C- GNU General Public License. The license should have
+//C- GNU General Public License, either version 2 of the license,
+//C- or (at your option) any later version. The license should have
 //C- accompanied the software or you may obtain a copy of the license
 //C- from the Free Software Foundation at http://www.fsf.org .
 //C-
@@ -14,7 +15,7 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: qdjviewsidebar.cpp,v 1.36 2007/01/10 01:19:12 leonb Exp $
+// $Id: qdjviewsidebar.cpp,v 1.44 2007/11/25 13:39:11 leonb Exp $
 
 #if AUTOCONF
 # include "config.h"
@@ -27,6 +28,7 @@
 #include <QAbstractListModel>
 #include <QAction>
 #include <QActionGroup>
+#include <QApplication>
 #include <QContextMenuEvent>
 #include <QCheckBox>
 #include <QDebug>
@@ -346,7 +348,6 @@ QDjViewThumbnails::View::View(QDjViewThumbnails *widget)
   setWrapping(true);
   setMovement(QListView::Static);
   setResizeMode(QListView::Adjust);
-  setLayoutMode(QListView::Batched);
   setSpacing(8);
 #if QT_VERSION >= 0x040100
   setUniformItemSizes(true);
@@ -356,6 +357,8 @@ QDjViewThumbnails::View::View(QDjViewThumbnails *widget)
   // we cannot do it efficiently in Model::makeData().
   connect((QObject*)verticalScrollBar(), SIGNAL(sliderMoved(int)),
           (QObject*)widget->model, SLOT(scheduleRefresh()) );
+  // Really too slow without this.
+  setLayoutMode(QListView::Batched);
 #endif
 }
 
@@ -396,8 +399,13 @@ QDjViewThumbnails::Model::Model(QDjViewThumbnails *widget)
     pageInProgress(-1)
 {
   // create format
-  unsigned int masks[4] = { 0xff0000, 0xff00, 0xff, 0xff000000 };
+#if DDJVUAPI_VERSION < 18
+  unsigned int masks[3] = { 0xff0000, 0xff00, 0xff };
   format = ddjvu_format_create(DDJVU_FORMAT_RGBMASK32, 3, masks);
+#else
+  unsigned int masks[4] = { 0xff0000, 0xff00, 0xff, 0xff000000 };
+  format = ddjvu_format_create(DDJVU_FORMAT_RGBMASK32, 4, masks);
+#endif
   ddjvu_format_set_row_order(format, true);
   ddjvu_format_set_y_direction(format, true);
   ddjvu_format_set_ditherbits(format, QPixmap::defaultDepth());
@@ -417,27 +425,43 @@ QDjViewThumbnails::Model::Model(QDjViewThumbnails *widget)
 void 
 QDjViewThumbnails::Model::documentClosed(QDjVuDocument *doc)
 {
-  names.clear();
+  if (names.size() > 0)
+    {
+      beginRemoveRows(QModelIndex(),0,names.size()-1);
+      names.clear();
+      pageInProgress = -1;
+      endRemoveRows();
+    }
   disconnect(doc, 0, this, 0);
-  emit layoutChanged();
 }
 
 
 void 
 QDjViewThumbnails::Model::documentReady(QDjVuDocument *doc)
 {
-  names.clear();
+  if (names.size() > 0)
+    {
+      beginRemoveRows(QModelIndex(),0,names.size()-1);
+      names.clear();
+      pageInProgress = -1;
+      endRemoveRows();
+    }
   int pagenum = djview->pageNum();
-  for (int pageno=0; pageno<pagenum; pageno++)
-    names << djview->pageName(pageno);
+  if (pagenum > 0)
+    {
+      beginInsertRows(QModelIndex(),0,pagenum-1);
+      for (int pageno=0; pageno<pagenum; pageno++)
+        names << djview->pageName(pageno);
+      endInsertRows();
+    }
   connect(doc, SIGNAL(thumbnail(int)),
           this, SLOT(thumbnail(int)) );
   connect(doc, SIGNAL(pageinfo()),
           this, SLOT(scheduleRefresh()) );
   connect(doc, SIGNAL(idle()),
           this, SLOT(scheduleRefresh()) );
-  emit layoutChanged();
   widget->pageChanged(djview->getDjVuWidget()->page());
+  scheduleRefresh();
 }
 
 
@@ -907,10 +931,13 @@ QDjViewFind::Model::data(const QModelIndex &index, int role) const
             case Qt::DisplayRole:
               return info.name;
             case Qt::ToolTipRole:
-              if (info.hits <= 1)
-                return tr("%1 hit").arg(info.hits);
-              else
-                return tr("%1 hits").arg(info.hits);
+              if (info.hits == 1)
+                return tr("1 hit");
+#if QT_VERSION >= 0x40020
+              return tr("%n hits", "qt>=4.2", info.hits);
+#else
+              return tr("%1 hits", "qt<4.2").arg(info.hits);
+#endif
             case Qt::WhatsThisRole:
               return widget->whatsThis();
             default:
@@ -977,10 +1004,15 @@ QDjViewFind::Model::modelAdd(int pageno, int hits)
   RowInfo info;
   info.pageno = pageno;
   info.hits = hits;
-  if (hits <= 1)
-    info.name = tr("Page %1 (%2 hit)").arg(name).arg(hits);
-  else
-    info.name = tr("Page %1 (%2 hits)").arg(name).arg(hits);
+  if (hits == 1)
+    info.name = tr("Page %1 (1 hit)").arg(name);
+  else {
+#if QT_VERSION >= 0x40200
+    info.name = tr("Page %1 (%n hits)", "qt>=4.2", hits).arg(name);
+#else
+    info.name = tr("Page %1 (%2 hits)", "qt<4.2").arg(name).arg(hits);
+#endif
+  }
   int lo = modelFind(pageno);
   if (lo < pages.size() && pages[lo].pageno == pageno)
     {
@@ -1446,7 +1478,7 @@ QDjViewFind::Model::textChanged()
       s = QRegExp::escape(widget->text());
       s.replace(QRegExp("\\s+"), " ");
       if (wordOnly)
-        s = "\\b" + s + "\\b";
+        s = "\\b" + s;
       find = QRegExp(s);
       if (caseSensitive)
         find.setCaseSensitivity(Qt::CaseSensitive);
