@@ -4,7 +4,8 @@
 //C- Copyright (c) 2006  Leon Bottou
 //C-
 //C- This software is subject to, and may be distributed under, the
-//C- GNU General Public License. The license should have
+//C- GNU General Public License, either version 2 of the license,
+//C- or (at your option) any later version. The license should have
 //C- accompanied the software or you may obtain a copy of the license
 //C- from the Free Software Foundation at http://www.fsf.org .
 //C-
@@ -14,7 +15,7 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: qdjvuwidget.h,v 1.20 2007/01/03 16:52:17 leonb Exp $
+// $Id: qdjvuwidget.h,v 1.23 2007/11/04 02:42:41 leonb Exp $
 
 #ifndef QDJVUWIDGET_H
 #define QDJVUWIDGET_H
@@ -147,6 +148,7 @@ public:
   
   QDjVuDocument *document(void) const;
   int page(void) const;
+  QPoint hotSpot(void) const;
   Position position(void) const;
   Position position(const QPoint &point) const;
   int rotation(void) const;
@@ -215,7 +217,7 @@ public:
   QString linkComment(void);
   QString getTextForRect(const QRect &rect);
   QImage  getImageForRect(const QRect &rect);
-  QDjVuPage *getDjVuPage(int pageno);
+  bool pageSizeKnown(int pageno) const;
   void clearHighlights(int pageno);
   void addHighlight(int pageno, int x, int y, int w, int h, QColor color);
   
